pymorphy3
=========

Morphological analyzer (POS tagger + inflection engine)
for Russian and Ukrainian languages.

## Links
Repo is fork of [Korobov Mykhail](https://github.com/kmike/pymorphy2) and follows all rules of MIT license.